#region GNU_GPL
// Copyright (c) 2003 The Ohio State University
//
// Anish Arora <anish@cis.ohio-state.edu>
// Jason O. Hallstrom <hallstro@cis.ohio-state.edu>
// William M. Leal <leal@cis.ohio-state.edu>
//
// This file is part of DVI.
//
// DVI is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// DVI is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with DVI; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#endregion


using System;
using System.Windows.Forms;
using System.ComponentModel;
using OSU.CallTracking;


namespace OSU.DVI.GUI.CallTracking
{
	
	public class MethodCallDialog : Form
	{
		#region Fields
		//-----------------------------------------------------------------
		// Fields
		//-----------------------------------------------------------------
		// This field is required by the Windows Form Designer
		private Container components = null;
		
		// The main group-box on the form
		private GroupBox gbMain;
		
		// The 'Invocation ID' label and text-box
		private Label lblInvocationID;
		private TextBox tbInvocationID;

		// The 'Date / Time' label and text-box
		private Label lblDateTime;
		private TextBox tbDateTime;

		// The 'Method Name' label and text-box
		private Label lblMethodName;
		private TextBox tbMethodName;
		
		// The 'Caller Address' label and text-box
		private Label lblCallerAddress;
		private TextBox tbCallerAddress;
		
		// The 'Target Address' label and text-box
		private Label lblTargetAddress;
		private TextBox tbTargetAddress;

		// The 'Arguments' label, list-view, and associated column headers
		private Label lblArguments;
		private ListView lvArguments;
		private ColumnHeader chType;
		private ColumnHeader chValue;
		
		// The 'OK' button at the bottom of the form
		private Button btnOK;
		//-----------------------------------------------------------------
		#endregion


		#region Constructors
		//-----------------------------------------------------------------
		// Constructors
		//-----------------------------------------------------------------
		public MethodCallDialog()
		{
			// Required for Windows Form Designer support
			InitializeComponent();
		}
		//-----------------------------------------------------------------
		#endregion


		#region Event Handlers
		//-----------------------------------------------------------------
		// Event Handlers
		//-----------------------------------------------------------------
		private void btnOK_Click(object objSource, EventArgs eaArgs)
		{	this.Visible = false;    }
		//-----------------------------------------------------------------
		#endregion


		#region Methods
		//-----------------------------------------------------------------
		// Methods
		//-----------------------------------------------------------------
		public void Show(CallLogEntry cleLogEntry)
		{
			// Populate the text-box fields
			tbInvocationID.Text = cleLogEntry.CallInformation.InvocationID.ToString();
			tbDateTime.Text = cleLogEntry.Timestamp.ToString();
			tbMethodName.Text = cleLogEntry.CallInformation.MethodName;
			tbCallerAddress.Text = cleLogEntry.CallerAddress.ToString();
			tbTargetAddress.Text = cleLogEntry.TargetAddress.ToString();

			// Populate the list-view
			lvArguments.Items.Clear();
			for(int intIndex = 0; intIndex < cleLogEntry.CallInformation.Arguments.Length; intIndex++)
			{
				ListViewItem lviItem = new ListViewItem(cleLogEntry.CallInformation.ParameterTypes[intIndex].ToString());
				lviItem.SubItems.Add(cleLogEntry.CallInformation.Arguments[intIndex].ToString());
				lvArguments.Items.Add(lviItem);
			}

			// Show the dialog
			base.Show();
		}

		protected override void Dispose(bool bolDisposing)
		{
			if((bolDisposing) && (components != null))
			{	components.Dispose();    }
				
			base.Dispose(bolDisposing);
		}
		//-----------------------------------------------------------------
		#endregion


		#region Windows Form Designer Generated Code
		//-----------------------------------------------------------------
		// Windows Form Designer Generated Code
		//-----------------------------------------------------------------
		// Required method for Windows Form Designer support - do not modify
		// the contents of this method with the code editor.
		//-----------------------------------------------------------------
		private void InitializeComponent()
		{
			this.gbMain = new System.Windows.Forms.GroupBox();
			this.lblCallerAddress = new System.Windows.Forms.Label();
			this.tbCallerAddress = new System.Windows.Forms.TextBox();
			this.lblArguments = new System.Windows.Forms.Label();
			this.lvArguments = new System.Windows.Forms.ListView();
			this.chType = new System.Windows.Forms.ColumnHeader();
			this.chValue = new System.Windows.Forms.ColumnHeader();
			this.lblMethodName = new System.Windows.Forms.Label();
			this.tbMethodName = new System.Windows.Forms.TextBox();
			this.lblDateTime = new System.Windows.Forms.Label();
			this.tbDateTime = new System.Windows.Forms.TextBox();
			this.lblInvocationID = new System.Windows.Forms.Label();
			this.tbInvocationID = new System.Windows.Forms.TextBox();
			this.lblTargetAddress = new System.Windows.Forms.Label();
			this.tbTargetAddress = new System.Windows.Forms.TextBox();
			this.btnOK = new System.Windows.Forms.Button();
			this.gbMain.SuspendLayout();
			this.SuspendLayout();
			// 
			// gbMain
			// 
			this.gbMain.Controls.AddRange(new System.Windows.Forms.Control[] {
																				 this.lblCallerAddress,
																				 this.tbCallerAddress,
																				 this.lblArguments,
																				 this.lvArguments,
																				 this.lblMethodName,
																				 this.tbMethodName,
																				 this.lblDateTime,
																				 this.tbDateTime,
																				 this.lblInvocationID,
																				 this.tbInvocationID,
																				 this.lblTargetAddress,
																				 this.tbTargetAddress});
			this.gbMain.Location = new System.Drawing.Point(9, 8);
			this.gbMain.Name = "gbMain";
			this.gbMain.Size = new System.Drawing.Size(495, 280);
			this.gbMain.TabIndex = 0;
			this.gbMain.TabStop = false;
			// 
			// lblCallerAddress
			// 
			this.lblCallerAddress.Font = new System.Drawing.Font("Microsoft Sans Serif", 8.25F, System.Drawing.FontStyle.Underline, System.Drawing.GraphicsUnit.Point, ((System.Byte)(0)));
			this.lblCallerAddress.Location = new System.Drawing.Point(256, 67);
			this.lblCallerAddress.Name = "lblCallerAddress";
			this.lblCallerAddress.Size = new System.Drawing.Size(100, 16);
			this.lblCallerAddress.TabIndex = 11;
			this.lblCallerAddress.Text = "Caller Address";
			// 
			// tbCallerAddress
			// 
			this.tbCallerAddress.Font = new System.Drawing.Font("Microsoft Sans Serif", 6.75F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((System.Byte)(0)));
			this.tbCallerAddress.Location = new System.Drawing.Point(256, 83);
			this.tbCallerAddress.Name = "tbCallerAddress";
			this.tbCallerAddress.ReadOnly = true;
			this.tbCallerAddress.Size = new System.Drawing.Size(224, 18);
			this.tbCallerAddress.TabIndex = 4;
			this.tbCallerAddress.Text = "";
			// 
			// lblArguments
			// 
			this.lblArguments.Font = new System.Drawing.Font("Microsoft Sans Serif", 8.25F, System.Drawing.FontStyle.Underline, System.Drawing.GraphicsUnit.Point, ((System.Byte)(0)));
			this.lblArguments.Location = new System.Drawing.Point(16, 156);
			this.lblArguments.Name = "lblArguments";
			this.lblArguments.Size = new System.Drawing.Size(100, 16);
			this.lblArguments.TabIndex = 9;
			this.lblArguments.Text = "Arguments";
			// 
			// lvArguments
			// 
			this.lvArguments.Columns.AddRange(new System.Windows.Forms.ColumnHeader[] {
																						  this.chType,
																						  this.chValue});
			this.lvArguments.Font = new System.Drawing.Font("Microsoft Sans Serif", 6.75F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((System.Byte)(0)));
			this.lvArguments.Location = new System.Drawing.Point(16, 172);
			this.lvArguments.MultiSelect = false;
			this.lvArguments.Name = "lvArguments";
			this.lvArguments.Size = new System.Drawing.Size(464, 97);
			this.lvArguments.TabIndex = 6;
			this.lvArguments.View = System.Windows.Forms.View.Details;
			// 
			// chType
			// 
			this.chType.Text = "Type";
			this.chType.Width = 220;
			// 
			// chValue
			// 
			this.chValue.Text = "Value";
			this.chValue.Width = 220;
			// 
			// lblMethodName
			// 
			this.lblMethodName.Font = new System.Drawing.Font("Microsoft Sans Serif", 8.25F, System.Drawing.FontStyle.Underline, System.Drawing.GraphicsUnit.Point, ((System.Byte)(0)));
			this.lblMethodName.Location = new System.Drawing.Point(16, 112);
			this.lblMethodName.Name = "lblMethodName";
			this.lblMethodName.Size = new System.Drawing.Size(100, 16);
			this.lblMethodName.TabIndex = 7;
			this.lblMethodName.Text = "Method Name";
			// 
			// tbMethodName
			// 
			this.tbMethodName.Font = new System.Drawing.Font("Microsoft Sans Serif", 6.75F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((System.Byte)(0)));
			this.tbMethodName.Location = new System.Drawing.Point(16, 128);
			this.tbMethodName.Name = "tbMethodName";
			this.tbMethodName.ReadOnly = true;
			this.tbMethodName.Size = new System.Drawing.Size(224, 18);
			this.tbMethodName.TabIndex = 5;
			this.tbMethodName.Text = "";
			// 
			// lblDateTime
			// 
			this.lblDateTime.Font = new System.Drawing.Font("Microsoft Sans Serif", 8.25F, System.Drawing.FontStyle.Underline, System.Drawing.GraphicsUnit.Point, ((System.Byte)(0)));
			this.lblDateTime.Location = new System.Drawing.Point(16, 67);
			this.lblDateTime.Name = "lblDateTime";
			this.lblDateTime.Size = new System.Drawing.Size(100, 16);
			this.lblDateTime.TabIndex = 5;
			this.lblDateTime.Text = "Date / Time";
			// 
			// tbDateTime
			// 
			this.tbDateTime.Font = new System.Drawing.Font("Microsoft Sans Serif", 6.75F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((System.Byte)(0)));
			this.tbDateTime.Location = new System.Drawing.Point(16, 84);
			this.tbDateTime.Name = "tbDateTime";
			this.tbDateTime.ReadOnly = true;
			this.tbDateTime.Size = new System.Drawing.Size(224, 18);
			this.tbDateTime.TabIndex = 3;
			this.tbDateTime.Text = "";
			// 
			// lblInvocationID
			// 
			this.lblInvocationID.Font = new System.Drawing.Font("Microsoft Sans Serif", 8.25F, System.Drawing.FontStyle.Underline, System.Drawing.GraphicsUnit.Point, ((System.Byte)(0)));
			this.lblInvocationID.Location = new System.Drawing.Point(16, 24);
			this.lblInvocationID.Name = "lblInvocationID";
			this.lblInvocationID.Size = new System.Drawing.Size(100, 16);
			this.lblInvocationID.TabIndex = 3;
			this.lblInvocationID.Text = "Invocation ID";
			// 
			// tbInvocationID
			// 
			this.tbInvocationID.Font = new System.Drawing.Font("Microsoft Sans Serif", 6.75F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((System.Byte)(0)));
			this.tbInvocationID.Location = new System.Drawing.Point(16, 40);
			this.tbInvocationID.Name = "tbInvocationID";
			this.tbInvocationID.ReadOnly = true;
			this.tbInvocationID.Size = new System.Drawing.Size(224, 18);
			this.tbInvocationID.TabIndex = 1;
			this.tbInvocationID.Text = "";
			// 
			// lblTargetAddress
			// 
			this.lblTargetAddress.Font = new System.Drawing.Font("Microsoft Sans Serif", 8.25F, System.Drawing.FontStyle.Underline, System.Drawing.GraphicsUnit.Point, ((System.Byte)(0)));
			this.lblTargetAddress.Location = new System.Drawing.Point(256, 24);
			this.lblTargetAddress.Name = "lblTargetAddress";
			this.lblTargetAddress.Size = new System.Drawing.Size(100, 16);
			this.lblTargetAddress.TabIndex = 1;
			this.lblTargetAddress.Text = "Target Address";
			// 
			// tbTargetAddress
			// 
			this.tbTargetAddress.Font = new System.Drawing.Font("Microsoft Sans Serif", 6.75F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((System.Byte)(0)));
			this.tbTargetAddress.Location = new System.Drawing.Point(256, 40);
			this.tbTargetAddress.Name = "tbTargetAddress";
			this.tbTargetAddress.ReadOnly = true;
			this.tbTargetAddress.Size = new System.Drawing.Size(224, 18);
			this.tbTargetAddress.TabIndex = 2;
			this.tbTargetAddress.Text = "";
			// 
			// btnOK
			// 
			this.btnOK.Anchor = System.Windows.Forms.AnchorStyles.None;
			this.btnOK.DialogResult = System.Windows.Forms.DialogResult.Cancel;
			this.btnOK.Location = new System.Drawing.Point(8, 296);
			this.btnOK.Name = "btnOK";
			this.btnOK.Size = new System.Drawing.Size(496, 23);
			this.btnOK.TabIndex = 7;
			this.btnOK.Text = "OK";
			this.btnOK.Click += new System.EventHandler(this.btnOK_Click);
			// 
			// MethodCallDialog
			// 
			this.AcceptButton = this.btnOK;
			this.AutoScaleBaseSize = new System.Drawing.Size(5, 13);
			this.CancelButton = this.btnOK;
			this.ClientSize = new System.Drawing.Size(514, 330);
			this.ControlBox = false;
			this.Controls.AddRange(new System.Windows.Forms.Control[] {
																		  this.btnOK,
																		  this.gbMain});
			this.FormBorderStyle = System.Windows.Forms.FormBorderStyle.FixedToolWindow;
			this.Name = "MethodCallDialog";
			this.Text = "Method Call Information";
			this.gbMain.ResumeLayout(false);
			this.ResumeLayout(false);

		}
		//-----------------------------------------------------------------
		#endregion
	}

}
