#region GNU_GPL
// Copyright (c) 2003 The Ohio State University
//
// Anish Arora <anish@cis.ohio-state.edu>
// Jason O. Hallstrom <hallstro@cis.ohio-state.edu>
// William M. Leal <leal@cis.ohio-state.edu>
//
// This file is part of DVI.
//
// DVI is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// DVI is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with DVI; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#endregion


using System;
using System.Threading;
using System.Collections;
using System.Windows.Forms;
using OSU.DRSS.ManagedObjects;
using OSU.DRSS.Platform;
using OSU.DRSS.Util;
using OSU.CallTracking;
using OSU.DVI.GUI.ManagedObjects;
using OSU.DVI.GUI.Dialogs;


namespace OSU.DVI.GUI.ControlInitializers
{
	
	public class ReceiveChainsControlInitializer
	{
		#region Fields
		//-----------------------------------------------------------------
		// Fields
		//-----------------------------------------------------------------
		// The 'Receive Chains' popup menu, and the associated menu items
		private ContextMenu cmReceiveChainsPopup;
		private MenuItem miViewInterceptors;
		private MenuItem miSeparator;
		private MenuItem miDeployCallTracking;

		// The underlying custom control to be initialized
		private RefreshableManagedObjectListViewControl ctrReceiveChainsPageControl;
		
		// A reference to the remote interceptor chain registry
		private PlatformInterceptorChainRegistry picRemoteRegistry;

		// The address of the local call log (for call tracking services)
		private PlatformHostedObjectAddress phoCallLogAddress;

		// The 'Receive Interceptors' dialog
		private ReceiveInterceptorsDialog dlgReceiveInterceptors;
		//-----------------------------------------------------------------
		#endregion


		#region Constructors
		//-----------------------------------------------------------------
		// Constructors
		//-----------------------------------------------------------------
		public ReceiveChainsControlInitializer(RefreshableManagedObjectListViewControl ctrReceiveChainsPageControl, PlatformInterceptorChainRegistry picRemoteRegistry, PlatformHostedObjectAddress phoCallLogAddress)
		{
			//---
			// Setup the 'Receive Chains' popup menu
			this.miViewInterceptors = new MenuItem("&View Interceptors");
			this.miSeparator = new MenuItem("-");
			this.miDeployCallTracking = new MenuItem("Deploy Call &Tracking");
			this.miViewInterceptors.Click += new EventHandler(miViewInterceptors_Click);
			this.miDeployCallTracking.Click += new EventHandler(miDeployCallTracking_Click);
			MenuItem[] miMenuItems = { miViewInterceptors, miSeparator, miDeployCallTracking };
			this.cmReceiveChainsPopup = new ContextMenu(miMenuItems);
			this.cmReceiveChainsPopup.Popup += new EventHandler(this.cmReceiveChainsPopup_Popup);
			//---

			this.ctrReceiveChainsPageControl = ctrReceiveChainsPageControl;
			this.picRemoteRegistry = picRemoteRegistry;	
			this.phoCallLogAddress = phoCallLogAddress;
			this.dlgReceiveInterceptors = new ReceiveInterceptorsDialog(picRemoteRegistry);
			this.dlgReceiveInterceptors.SystemEvent += new SystemEventDelegate(SystemEvent_Forwarder);
		}
		//-----------------------------------------------------------------
		#endregion


		#region Event Handlers
		//-----------------------------------------------------------------
		// Event Handlers
		//-----------------------------------------------------------------
		private void cmReceiveChainsPopup_Popup(object objSource, EventArgs eaArgs)
		{	
			bool bolItemSelected = (ctrReceiveChainsPageControl.SelectedItems.Count > 0);
			miViewInterceptors.Enabled = bolItemSelected;
			miDeployCallTracking.Enabled = bolItemSelected;
		}

		private void miViewInterceptors_Click(object objSource, EventArgs eaArgs)
		{
			// Retrieve the managed object information for the selected receive chain
			ManagedObjectInformation moiReceiveChain = (ManagedObjectInformation) ctrReceiveChainsPageControl.SelectedItems[0].Tag;
			
			// Disable the page control until the 'Receive Interceptors' dialog closes
			ctrReceiveChainsPageControl.Enabled = false;

			//---
			// Startup a thread to handle the dialog display
			ThreadWithArgumentsStart twaHandleInterceptorsDialogDisplay = new ThreadWithArgumentsStart(HandleInterceptorsDialogDisplayThreadBody);
			Thread thdHandleInterceptorsDialogDisplay = ThreadWithArgumentsFactory.CreateThread(twaHandleInterceptorsDialogDisplay, moiReceiveChain.ObjectID);
			thdHandleInterceptorsDialogDisplay.IsBackground = true;
			thdHandleInterceptorsDialogDisplay.Start();
			//---
		}

		private void miDeployCallTracking_Click(object objSource, EventArgs eaArgs)
		{
			// Retrieve the managed object information for the selected receive chain
			ManagedObjectInformation moiReceiveChain = (ManagedObjectInformation) ctrReceiveChainsPageControl.SelectedItems[0].Tag;
			
			//---
			// Startup a thread to deploy call tracking services to the selected chain
			ThreadWithArgumentsStart twaDeployCallTracking = new ThreadWithArgumentsStart(DeployCallTrackingThreadBody);
			Thread thdDeployCallTracking = ThreadWithArgumentsFactory.CreateThread(twaDeployCallTracking, moiReceiveChain.ObjectID);
			thdDeployCallTracking.IsBackground = true;
			thdDeployCallTracking.Start();
			//---
		}

		private void SystemEvent_Forwarder(object objSource, SystemEventArgs seaArgs)
		{	RaiseSystemEvent(seaArgs.Message);    }
		//-----------------------------------------------------------------
		#endregion


		#region Methods
		//-----------------------------------------------------------------
		// Methods
		//-----------------------------------------------------------------
		public void InitializeControl()
		{	ctrReceiveChainsPageControl.InitializeControl(cmReceiveChainsPopup, "RC", new ManagedObjectProducerDelegate(picRemoteRegistry.GetRIChains));    }

		private void HandleInterceptorsDialogDisplayThreadBody(object objChainID)
		{
			try
			{
				// Retrieve the interceptor information for the specified chain
				Guid guiChainID = (Guid) objChainID;
				RaiseSystemEvent("Retrieving interceptor information for chain [" + guiChainID + "].");
				IEnumerator enmReceiveInterceptors = picRemoteRegistry.GetRIChainElements(guiChainID);
				dlgReceiveInterceptors.ShowDialog(guiChainID, enmReceiveInterceptors);
			}
			catch(Exception exc)
			{	RaiseSystemEvent(exc.ToString());    }

			// Re-enable the page control
			ctrReceiveChainsPageControl.Enabled = true;
		}

		private void DeployCallTrackingThreadBody(object objReceiveChainID)
		{
			try
			{
				//---
				// Deploy the call tracking interceptor
				Guid guiReceiveChainID = (Guid) objReceiveChainID;
				RaiseSystemEvent("Deploying call tracking interceptor to receive chain [" + guiReceiveChainID + "].");
				object[] objArguments = { phoCallLogAddress };
				picRemoteRegistry.RegisterReceiveInterceptor(guiReceiveChainID, 0, typeof(CallTrackingReceiveInterceptor), objArguments);
				RaiseSystemEvent("Call tracking interceptor deployed.");
				//---
			}
			catch(Exception exc)
			{	RaiseSystemEvent(exc.ToString());    }
		}

		private void RaiseSystemEvent(string strMessage)
		{
			if(SystemEvent != null)
			{	SystemEvent(this, new SystemEventArgs("RC: " + strMessage));    }
		}
		//-----------------------------------------------------------------
		#endregion


		#region Events
		//-----------------------------------------------------------------
		// Events
		//-----------------------------------------------------------------
		// This event is raised internally whenever something of interest 
		// occurs within a worker thread
		public event SystemEventDelegate SystemEvent;
		//-----------------------------------------------------------------
		#endregion
	}

}
