#region GNU_GPL
// Copyright (c) 2003 The Ohio State University
//
// Anish Arora <anish@cis.ohio-state.edu>
// Jason O. Hallstrom <hallstro@cis.ohio-state.edu>
// William M. Leal <leal@cis.ohio-state.edu>
//
// This file is part of DVI.
//
// DVI is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// DVI is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with DVI; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#endregion


using System;
using System.Threading;
using System.Collections;
using System.Windows.Forms;
using OSU.DRSS.ManagedObjects;
using OSU.DRSS.Platform;
using OSU.DRSS.Util;
using OSU.DVI.GUI.Dialogs;
using OSU.DVI.GUI.ManagedObjects;


namespace OSU.DVI.GUI.ControlInitializers
{
	
	public class SendChainsControlInitializer
	{
		#region Fields
		//-----------------------------------------------------------------
		// Fields
		//-----------------------------------------------------------------
		// The 'Send Chains' popup menu, and the associated menu items
		private ContextMenu cmSendChainsPopup;
		private MenuItem miViewInterceptors;

		// The underlying custom control to be initialized
		private RefreshableManagedObjectListViewControl ctrSendChainsPageControl;
		
		// A reference to the remote interceptor chain registry
		private PlatformInterceptorChainRegistry picRemoteRegistry;

		// The 'Send Interceptors' dialog
		private SendInterceptorsDialog dlgSendInterceptors;
		//-----------------------------------------------------------------
		#endregion


		#region Constructors
		//-----------------------------------------------------------------
		// Constructors
		//-----------------------------------------------------------------
		public SendChainsControlInitializer(RefreshableManagedObjectListViewControl ctrSendChainsPageControl, PlatformInterceptorChainRegistry picRemoteRegistry)
		{
			//---
			// Setup the 'Send Chains' popup menu
			this.miViewInterceptors = new MenuItem("&View Interceptors");
			this.miViewInterceptors.Click += new EventHandler(miViewInterceptors_Click);
			MenuItem[] miMenuItems = { miViewInterceptors };
			this.cmSendChainsPopup = new ContextMenu(miMenuItems);
			this.cmSendChainsPopup.Popup += new EventHandler(this.cmSendChainsPopup_Popup);
			//---

			this.ctrSendChainsPageControl = ctrSendChainsPageControl;
			this.picRemoteRegistry = picRemoteRegistry;	
			this.dlgSendInterceptors = new SendInterceptorsDialog(picRemoteRegistry);
			this.dlgSendInterceptors.SystemEvent += new SystemEventDelegate(SystemEvent_Forwarder);
		}
		//-----------------------------------------------------------------
		#endregion


		#region Event Handlers
		//-----------------------------------------------------------------
		// Event Handlers
		//-----------------------------------------------------------------
		private void cmSendChainsPopup_Popup(object objSource, EventArgs eaArgs)
		{	
			bool bolItemSelected = (ctrSendChainsPageControl.SelectedItems.Count > 0);
			miViewInterceptors.Enabled = bolItemSelected;
		}

		private void miViewInterceptors_Click(object objSource, EventArgs eaArgs)
		{
			// Retrieve the managed object information for the selected send chain
			ManagedObjectInformation moiSendChain = (ManagedObjectInformation) ctrSendChainsPageControl.SelectedItems[0].Tag;
			
			// Disable the page control until the 'Send Interceptors' dialog closes
			ctrSendChainsPageControl.Enabled = false;

			//---
			// Startup a thread to handle the dialog display
			ThreadWithArgumentsStart twaHandleInterceptorsDialogDisplay = new ThreadWithArgumentsStart(HandleInterceptorsDialogDisplayThreadBody);
			Thread thdHandleInterceptorsDialogDisplay = ThreadWithArgumentsFactory.CreateThread(twaHandleInterceptorsDialogDisplay, moiSendChain.ObjectID);
			thdHandleInterceptorsDialogDisplay.IsBackground = true;
			thdHandleInterceptorsDialogDisplay.Start();
			//---
		}

		private void SystemEvent_Forwarder(object objSource, SystemEventArgs seaArgs)
		{	RaiseSystemEvent(seaArgs.Message);    }
		//-----------------------------------------------------------------
		#endregion


		#region Methods
		//-----------------------------------------------------------------
		// Methods
		//-----------------------------------------------------------------
		public void InitializeControl()
		{	ctrSendChainsPageControl.InitializeControl(cmSendChainsPopup, "SC", new ManagedObjectProducerDelegate(picRemoteRegistry.GetSIChains));    }

		private void HandleInterceptorsDialogDisplayThreadBody(object objChainID)
		{
			try
			{
				// Retrieve the interceptor information for the specified chain
				Guid guiChainID = (Guid) objChainID;
				RaiseSystemEvent("Retrieving interceptor information for chain [" + guiChainID + "].");
				IEnumerator enmSendInterceptors = picRemoteRegistry.GetSIChainElements(guiChainID);
				dlgSendInterceptors.ShowDialog(guiChainID, enmSendInterceptors);
			}
			catch(Exception exc)
			{	RaiseSystemEvent(exc.ToString());    }

			// Re-enable the page control
			ctrSendChainsPageControl.Enabled = true;
		}

		private void RaiseSystemEvent(string strMessage)
		{
			if(SystemEvent != null)
			{	SystemEvent(this, new SystemEventArgs("RC: " + strMessage));    }
		}
		//-----------------------------------------------------------------
		#endregion


		#region Events
		//-----------------------------------------------------------------
		// Events
		//-----------------------------------------------------------------
		// This event is raised internally whenever something of interest 
		// occurs within a worker thread
		public event SystemEventDelegate SystemEvent;
		//-----------------------------------------------------------------
		#endregion
	}

}
