#region GNU_GPL
// Copyright (c) 2003 The Ohio State University
//
// Anish Arora <anish@cis.ohio-state.edu>
// Jason O. Hallstrom <hallstro@cis.ohio-state.edu>
// William M. Leal <leal@cis.ohio-state.edu>
//
// This file is part of DVI.
//
// DVI is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// DVI is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with DVI; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#endregion


using System;
using System.Threading;
using System.Collections;
using System.Windows.Forms;
using OSU.DRSS.Platform;
using OSU.DRSS.Util;
using OSU.DVI.GUI.ManagedObjects;


namespace OSU.DVI.GUI.Dialogs
{
	
	public abstract class InterceptorsDialog
	{
		#region Fields
		//-----------------------------------------------------------------
		// Fields
		//-----------------------------------------------------------------
		// The generic 'Managed Objects' dialog configured as an 'Interceptors Dialog'
		private ManagedObjectListViewDialog dlgInterceptors;
		
		// The 'Interceptors' popup menu
		private ContextMenu cmInterceptorsPopup;

		// The 'Remove Interceptor' menu item
		private MenuItem miRemoveInterceptor;

		// The string to prepend to all event messages generated by worker
		// threads
		private string strEventMessagePrefix;

		// A reference to the remote interceptor chain registry 
		private PlatformInterceptorChainRegistry picRemoteRegistry;

		// When a list of interceptors is displayed, this field stores
		// the ID of the corresponding interceptor chain
		private Guid guiChainID;
		//-----------------------------------------------------------------
		#endregion


		#region Constructors
		//-----------------------------------------------------------------
		// Constructors
		//-----------------------------------------------------------------
		public InterceptorsDialog(string strTitle, string strEventMessagePrefix, PlatformInterceptorChainRegistry picRemoteRegistry)
		{
			this.strEventMessagePrefix = strEventMessagePrefix;
			this.picRemoteRegistry = picRemoteRegistry;
			this.guiChainID = Guid.Empty;

			//---
			// Setup the 'Interceptors' popup menu
			this.miRemoveInterceptor = new MenuItem("&Remove Interceptor");
			this.miRemoveInterceptor.Click += new EventHandler(miRemoveInterceptor_Click);
			MenuItem[] miMenuItems = { miRemoveInterceptor };
			this.cmInterceptorsPopup = new ContextMenu(miMenuItems);
			this.cmInterceptorsPopup.Popup += new EventHandler(cmInterceptorsPopup_Popup);
			//---
		
			// Create the underlying dialog
			this.dlgInterceptors = new ManagedObjectListViewDialog(cmInterceptorsPopup);
			this.dlgInterceptors.Text = strTitle;
		}
		//-----------------------------------------------------------------
		#endregion


		#region Event Handlers
		//-----------------------------------------------------------------
		// Event Handlers
		//-----------------------------------------------------------------
		private void cmInterceptorsPopup_Popup(object objSource, EventArgs eaArgs)
		{	miRemoveInterceptor.Enabled = (dlgInterceptors.SelectedItems.Count > 0);    }

		private void miRemoveInterceptor_Click(object objSource, EventArgs eaArgs)
		{
			object objSelectedItem = dlgInterceptors.SelectedItems[0];

			//---
			// Startup a thread to handle the remove request
			ThreadWithArgumentsStart twaRemoveInterceptorThread = new ThreadWithArgumentsStart(RemoveInterceptorThreadBody);
			Thread thdRemoveInterceptorThread = ThreadWithArgumentsFactory.CreateThread(twaRemoveInterceptorThread, objSelectedItem);
			thdRemoveInterceptorThread.IsBackground = true;
			thdRemoveInterceptorThread.Start();
			//---
		}
		//-----------------------------------------------------------------
		#endregion


		#region Methods
		//-----------------------------------------------------------------
		// Methods
		//-----------------------------------------------------------------
		public void ShowDialog(Guid guiChainID, IEnumerator enmInterceptors)
		{
			this.guiChainID = guiChainID;
			this.dlgInterceptors.ShowDialog(enmInterceptors);
		}

		private void RemoveInterceptorThreadBody(object objSelectedItem)
		{
			try
			{
				ListViewItem lviSelectedItem = (ListViewItem) objSelectedItem;
				RaiseSystemEvent("Removing interceptor at index [" + lviSelectedItem.Index + "] from chain [" + guiChainID + "].");
				RemoveInterceptor(picRemoteRegistry, guiChainID, lviSelectedItem.Index);
				RaiseSystemEvent("Interceptor removed.");

				// Remove the interceptor from the list-view
				lviSelectedItem.Remove();
			}
			catch(Exception exc)
			{	RaiseSystemEvent(exc.ToString());    }
		}

		protected abstract void RemoveInterceptor(PlatformInterceptorChainRegistry picRemoteRegistry, Guid guiChainID, int intIndex);
		
		private void RaiseSystemEvent(string strMessage)
		{
			if(SystemEvent != null)
			{	
				string strFormattedMessage = (strEventMessagePrefix != null) ? strEventMessagePrefix + ": " + strMessage : strMessage;				
				SystemEvent(this, new SystemEventArgs(strFormattedMessage));    
			}
		}
		//-----------------------------------------------------------------
		#endregion


		#region Events
		//-----------------------------------------------------------------
		// Events
		//-----------------------------------------------------------------
		// This event is raised internally whenever something of interest 
		// occurs within a worker thread
		public event SystemEventDelegate SystemEvent;
		//-----------------------------------------------------------------
		#endregion
	}

}
