#region GNU_GPL
// Copyright (c) 2003 The Ohio State University
//
// Anish Arora <anish@cis.ohio-state.edu>
// Jason O. Hallstrom <hallstro@cis.ohio-state.edu>
// William M. Leal <leal@cis.ohio-state.edu>
//
// This file is part of DVI.
//
// DVI is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// DVI is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with DVI; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#endregion


using System;
using System.Net;
using System.ComponentModel;
using System.Windows.Forms;


namespace OSU.DVI.GUI.Dialogs
{
	
	public class RequestAddressForm : Form
	{
		#region Fields
		//-----------------------------------------------------------------
		// Fields
		//-----------------------------------------------------------------
		// This field is required by the Windows Form Designer
		private Container components = null;

		// The message prompt to be displayed
		private Label lblMessage;

		// The main group-box 
		private GroupBox gbMain;
		
		// The 'IP Address" label and text-box
		private Label lblIPAddress;
		private TextBox tbIPAddress;

		// The 'Port Number' label and text-box
		private Label lblPortNumber;
		private TextBox tbPortNumber;
		
		// The buttons at the bottom of the form
		private Button btnOK;
		private Button btnCancel;
		//-----------------------------------------------------------------
		#endregion


		#region Constructors
		//-----------------------------------------------------------------
		// Constructors
		//-----------------------------------------------------------------
		public RequestAddressForm(string strMessage)
		{
			// Required for Windows Form Designer support
			InitializeComponent();

			// Set the message prompt to be displayed
			this.Message = strMessage;
		}
		//-----------------------------------------------------------------
		#endregion


		#region Properties
		//-----------------------------------------------------------------
		// Properties
		//-----------------------------------------------------------------
		public string Message
		{
			get
			{	return(lblMessage.Text);    }

			set
			{	lblMessage.Text = value;    }
		}

		public IPEndPoint IPEndPoint
		{
			get
			{	
				// Return an IPEndPoint instance that contains the (properly typed) IP address and port number
				// entered on the form.  If the form data is invalid, return null
				try
				{	return(new IPEndPoint(IPAddress.Parse(tbIPAddress.Text), int.Parse(tbPortNumber.Text)));    }
				catch(Exception exc)
				{	
					exc.ToString();
					return(null);    
				}
			}
		}
		//-----------------------------------------------------------------
		#endregion


		#region Event Handlers
		//-----------------------------------------------------------------
		// Event Handlers
		//-----------------------------------------------------------------
		private void btnOK_Click(object objSource, EventArgs eaArgs)
		{
			// Verify that the form data is syntactically correct.  If the data 
			// on the form is invalid, an error message will be displayed, and 
			// the form will remain open
			try
			{	
				IPAddress.Parse(tbIPAddress.Text);    
				int.Parse(tbPortNumber.Text);
				this.DialogResult = DialogResult.OK;
			}
			catch(Exception exc)
			{	
				// Do not accept the form input
				this.DialogResult = DialogResult.None;
				
				// Let the user know that the form data is invalid
				string strTitle = "Invalid IP Address and/or Port Number";
				string strMessage = "An invalid IP Address and/or port number was provided.\n\n" + exc.Message;
				MessageBox.Show(strMessage, strTitle, MessageBoxButtons.OK, MessageBoxIcon.Exclamation);
			}
		}

		private void RequestAddressForm_Activated(object objSource, EventArgs eaArgs)
		{	tbIPAddress.Focus();    }
		//-----------------------------------------------------------------
		#endregion

		
		#region Methods
		//-----------------------------------------------------------------
		// Methods
		//-----------------------------------------------------------------
		public new DialogResult ShowDialog(IWin32Window winOwner)
		{
			// Clear out the form fields and display the form
			tbIPAddress.Text = "";
			tbPortNumber.Text = "";
			return(base.ShowDialog(winOwner));
		}
		
		protected override void Dispose(bool bolDisposing)
		{
			if((bolDisposing) && (components != null))
			{	components.Dispose();    }
			
			base.Dispose(bolDisposing);
		}
		//-----------------------------------------------------------------
		#endregion


		#region Windows Form Designer Generated Code
		//-----------------------------------------------------------------
		// Windows Form Designer Generated Code
		//-----------------------------------------------------------------
		// Required method for Windows Form Designer support - do not modify
		// the contents of this method with the code editor.
		//-----------------------------------------------------------------
		private void InitializeComponent()
		{
			this.lblMessage = new System.Windows.Forms.Label();
			this.gbMain = new System.Windows.Forms.GroupBox();
			this.tbIPAddress = new System.Windows.Forms.TextBox();
			this.lblPortNumber = new System.Windows.Forms.Label();
			this.lblIPAddress = new System.Windows.Forms.Label();
			this.tbPortNumber = new System.Windows.Forms.TextBox();
			this.btnOK = new System.Windows.Forms.Button();
			this.btnCancel = new System.Windows.Forms.Button();
			this.gbMain.SuspendLayout();
			this.SuspendLayout();
			// 
			// lblMessage
			// 
			this.lblMessage.Font = new System.Drawing.Font("Microsoft Sans Serif", 9F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((System.Byte)(0)));
			this.lblMessage.Location = new System.Drawing.Point(9, 8);
			this.lblMessage.Name = "lblMessage";
			this.lblMessage.Size = new System.Drawing.Size(288, 40);
			this.lblMessage.TabIndex = 0;
			this.lblMessage.TextAlign = System.Drawing.ContentAlignment.MiddleCenter;
			// 
			// gbMain
			// 
			this.gbMain.Controls.AddRange(new System.Windows.Forms.Control[] {
																				 this.tbIPAddress,
																				 this.lblPortNumber,
																				 this.lblIPAddress,
																				 this.tbPortNumber});
			this.gbMain.Location = new System.Drawing.Point(9, 54);
			this.gbMain.Name = "gbMain";
			this.gbMain.Size = new System.Drawing.Size(288, 88);
			this.gbMain.TabIndex = 0;
			this.gbMain.TabStop = false;
			// 
			// tbIPAddress
			// 
			this.tbIPAddress.Location = new System.Drawing.Point(85, 23);
			this.tbIPAddress.Name = "tbIPAddress";
			this.tbIPAddress.Size = new System.Drawing.Size(187, 20);
			this.tbIPAddress.TabIndex = 1;
			this.tbIPAddress.Text = "";
			// 
			// lblPortNumber
			// 
			this.lblPortNumber.Location = new System.Drawing.Point(8, 55);
			this.lblPortNumber.Name = "lblPortNumber";
			this.lblPortNumber.Size = new System.Drawing.Size(72, 20);
			this.lblPortNumber.TabIndex = 1;
			this.lblPortNumber.Text = "Port Number.";
			// 
			// lblIPAddress
			// 
			this.lblIPAddress.Location = new System.Drawing.Point(8, 23);
			this.lblIPAddress.Name = "lblIPAddress";
			this.lblIPAddress.Size = new System.Drawing.Size(72, 20);
			this.lblIPAddress.TabIndex = 0;
			this.lblIPAddress.Text = "IP Address.";
			// 
			// tbPortNumber
			// 
			this.tbPortNumber.Location = new System.Drawing.Point(85, 53);
			this.tbPortNumber.Name = "tbPortNumber";
			this.tbPortNumber.Size = new System.Drawing.Size(75, 20);
			this.tbPortNumber.TabIndex = 2;
			this.tbPortNumber.Text = "";
			// 
			// btnOK
			// 
			this.btnOK.Location = new System.Drawing.Point(68, 152);
			this.btnOK.Name = "btnOK";
			this.btnOK.TabIndex = 3;
			this.btnOK.Text = "OK";
			this.btnOK.Click += new System.EventHandler(this.btnOK_Click);
			// 
			// btnCancel
			// 
			this.btnCancel.DialogResult = System.Windows.Forms.DialogResult.Cancel;
			this.btnCancel.Location = new System.Drawing.Point(164, 152);
			this.btnCancel.Name = "btnCancel";
			this.btnCancel.TabIndex = 4;
			this.btnCancel.Text = "Cancel";
			// 
			// RequestAddressForm
			// 
			this.AcceptButton = this.btnOK;
			this.AutoScaleBaseSize = new System.Drawing.Size(5, 13);
			this.CancelButton = this.btnCancel;
			this.ClientSize = new System.Drawing.Size(306, 186);
			this.Controls.AddRange(new System.Windows.Forms.Control[] {
																		  this.gbMain,
																		  this.lblMessage,
																		  this.btnOK,
																		  this.btnCancel});
			this.FormBorderStyle = System.Windows.Forms.FormBorderStyle.FixedToolWindow;
			this.MaximizeBox = false;
			this.MinimizeBox = false;
			this.Name = "RequestAddressForm";
			this.ShowInTaskbar = false;
			this.StartPosition = System.Windows.Forms.FormStartPosition.CenterParent;
			this.Text = "Please Enter the IP Address and Port Number";
			this.Activated += new System.EventHandler(this.RequestAddressForm_Activated);
			this.gbMain.ResumeLayout(false);
			this.ResumeLayout(false);

		}
		//-----------------------------------------------------------------
		#endregion
	}

}
