#region GNU_GPL
// Copyright (c) 2003 The Ohio State University
//
// Anish Arora <anish@cis.ohio-state.edu>
// Jason O. Hallstrom <hallstro@cis.ohio-state.edu>
// William M. Leal <leal@cis.ohio-state.edu>
//
// This file is part of DVI.
//
// DVI is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// DVI is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with DVI; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#endregion


using System;
using System.Drawing;
using System.Collections;
using System.Windows.Forms;
using System.ComponentModel;
using OSU.DRSS.ManagedObjects;


namespace OSU.DVI.GUI.ManagedObjects
{
	
	public class ManagedObjectListViewControl : UserControl
	{
		#region Fields
		//-----------------------------------------------------------------
		// Fields
		//-----------------------------------------------------------------
		// This field is required by the Windows Control Designer
		private Container components = null;

		// The 'Managed Objects' list-view, and the associated column headers
		private ListView lvManagedObjects;
		private ColumnHeader chName;
		private ColumnHeader chDescription;
		//-----------------------------------------------------------------
		#endregion

		
		#region Constructors
		//-----------------------------------------------------------------
		// Constructors
		//-----------------------------------------------------------------
		public ManagedObjectListViewControl()
		{
			// This call is required by the Windows Control Designer.
			InitializeComponent();

			// Fire an artificial resize event so that the column headers
			// are sized appropriately
			this.lvManagedObjects_Resize(null, EventArgs.Empty);
		}
		//-----------------------------------------------------------------
		#endregion

		
		#region Properties
		//-----------------------------------------------------------------
		// Properties
		//-----------------------------------------------------------------
		public ListView.SelectedListViewItemCollection SelectedItems
		{
			get
			{	return(lvManagedObjects.SelectedItems);    }
		}
		//-----------------------------------------------------------------
		#endregion

		
		#region Event Handlers
		//-----------------------------------------------------------------
		// Event Handlers
		//-----------------------------------------------------------------
		private void lvManagedObjects_Resize(object objSource, EventArgs eaArgs)
		{
			// When the list-view is resized (e.g. due to resizing the form), resize
			// the associated column headers
			chName.Width = (int) (lvManagedObjects.Width * .35);
			chDescription.Width = (int) (lvManagedObjects.Width * .60);
		}
		//-----------------------------------------------------------------
		#endregion


		#region Methods
		//-----------------------------------------------------------------
		// Methods
		//-----------------------------------------------------------------		
		public void InitializeControl(ContextMenu cmManagedObjectsPopup)
		{	lvManagedObjects.ContextMenu = cmManagedObjectsPopup;    }

		public void RefreshManagedObjects(IEnumerator enmManagedObjects)
		{
			// Refresh the list-view to reflect the managed objects contained in enmManagedObjects
			lvManagedObjects.Items.Clear();
			while(enmManagedObjects.MoveNext())
			{
				ManagedObjectInformation moiManagedObject = (ManagedObjectInformation) enmManagedObjects.Current;
				ListViewItem lviNewItem = new ListViewItem(moiManagedObject.Name);
				lviNewItem.Tag = moiManagedObject;
				lviNewItem.SubItems.Add(moiManagedObject.Description);
				lvManagedObjects.Items.Add(lviNewItem);
			}
		}

		protected override void Dispose(bool bolDisposing)
		{
			if((bolDisposing)  && (components != null))
			{	components.Dispose();    }
			
			base.Dispose(bolDisposing);
		}
		//-----------------------------------------------------------------		
		#endregion


		#region Component Designer Generated Code
		//-----------------------------------------------------------------
		// Component Designer Generated Code
		//-----------------------------------------------------------------		
		// Required method for Windows Control Designer support - do not 
		// modify the contents of this method with the code editor.
		//-----------------------------------------------------------------		
		private void InitializeComponent()
		{
			this.lvManagedObjects = new System.Windows.Forms.ListView();
			this.chName = new System.Windows.Forms.ColumnHeader();
			this.chDescription = new System.Windows.Forms.ColumnHeader();
			this.SuspendLayout();
			// 
			// lvManagedObjects
			// 
			this.lvManagedObjects.Anchor = (((System.Windows.Forms.AnchorStyles.Top | System.Windows.Forms.AnchorStyles.Bottom) 
				| System.Windows.Forms.AnchorStyles.Left) 
				| System.Windows.Forms.AnchorStyles.Right);
			this.lvManagedObjects.Columns.AddRange(new System.Windows.Forms.ColumnHeader[] {
																							   this.chName,
																							   this.chDescription});
			this.lvManagedObjects.Font = new System.Drawing.Font("Microsoft Sans Serif", 6.75F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((System.Byte)(0)));
			this.lvManagedObjects.Location = new System.Drawing.Point(8, 8);
			this.lvManagedObjects.Name = "lvManagedObjects";
			this.lvManagedObjects.Size = new System.Drawing.Size(216, 80);
			this.lvManagedObjects.TabIndex = 2;
			this.lvManagedObjects.View = System.Windows.Forms.View.Details;
			this.lvManagedObjects.Resize += new System.EventHandler(this.lvManagedObjects_Resize);
			// 
			// chName
			// 
			this.chName.Text = "Name";
			// 
			// chDescription
			// 
			this.chDescription.Text = "Description";
			// 
			// ManagedObjectsListViewControl
			// 
			this.Controls.AddRange(new System.Windows.Forms.Control[] {
																		  this.lvManagedObjects});
			this.Name = "ManagedObjectsListViewControl";
			this.Size = new System.Drawing.Size(232, 96);
			this.ResumeLayout(false);
		}
		//-----------------------------------------------------------------		
		#endregion
	}

}
