#region GNU_GPL
// Copyright (c) 2003 The Ohio State University
//
// Anish Arora <anish@cis.ohio-state.edu>
// Jason O. Hallstrom <hallstro@cis.ohio-state.edu>
// William M. Leal <leal@cis.ohio-state.edu>
//
// This file is part of DRSS.
//
// DRSS is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// DRSS is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with DRSS; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#endregion


using System;
using System.Drawing;


namespace OSU.DVI.GUI.Rendering
{
	
	public class ShapeRenderingUtilities
	{
		#region Constructors
		//-----------------------------------------------------------------
		// Constructors
		//-----------------------------------------------------------------
		private ShapeRenderingUtilities()
		{	/* Utility Class */    }
		//-----------------------------------------------------------------
		#endregion


		#region Methods
		//-----------------------------------------------------------------
		// Methods
		//-----------------------------------------------------------------
		public static void DrawArrow(Graphics grpCanvas, Pen penPen, Brush brsBrush, Point pntFrom, Point pntTo, double dblHeadWidth, double dblHeadTheta)
		{
			// Draw the main body of the arrow
			grpCanvas.DrawLine(penPen, pntFrom, pntTo);
			
			//---
			// Calculate the center point at the base of the arrow head 
			double dblDeltaArrowX = (pntTo.X - pntFrom.X);
			double dblDeltaArrowY = (pntTo.Y - pntFrom.Y);
			double dblArrowLength = Math.Sqrt(Math.Pow(dblDeltaArrowX, 2.0) + Math.Pow(dblDeltaArrowY, 2.0));
			double dblHeadHeight = 0.5 * dblHeadWidth * Math.Tan(Math.PI/2.0 - dblHeadTheta/2.0);
			double dblU = (dblArrowLength != 0.0) ? (dblArrowLength - dblHeadHeight) / dblArrowLength : 1.0;
			double dblCenterHeadBaseX = pntFrom.X + dblU * dblDeltaArrowX;
			double dblCenterHeadBaseY = pntFrom.Y + dblU * dblDeltaArrowY;
			//---
			
			//---
			// Calculate the left and right points at the base of the arrow head
			double dblDeltaHeadBaseX;
			double dblDeltaHeadBaseY;
			if(dblDeltaArrowY == 0.0)
			{
				dblDeltaHeadBaseX = 0.0;
				dblDeltaHeadBaseY = dblHeadWidth;
			}
			else
			{
				double dblHeadBaseSlope = -(dblDeltaArrowX / dblDeltaArrowY);
				dblDeltaHeadBaseX = dblHeadWidth * Math.Sqrt(1.0 / (Math.Pow(dblHeadBaseSlope, 2.0) + 1.0));
				dblDeltaHeadBaseY  = dblDeltaHeadBaseX * dblHeadBaseSlope;
			}

			int intLeftHeadBaseX = (int) ((double) dblCenterHeadBaseX + (0.5 * dblDeltaHeadBaseX));
			int intLeftHeadBaseY = (int) ((double) dblCenterHeadBaseY + (0.5 * dblDeltaHeadBaseY));
			Point pntLeftHeadBase = new Point(intLeftHeadBaseX, intLeftHeadBaseY);

			int intRightHeadBaseX = (int) ((double) dblCenterHeadBaseX - (0.5 * dblDeltaHeadBaseX));
			int intRightHeadBaseY = (int) ((double) dblCenterHeadBaseY - (0.5 * dblDeltaHeadBaseY));
			Point pntRightHeadBase = new Point(intRightHeadBaseX, intRightHeadBaseY);
			//---

			//---
			// Draw the arrow head
			Point[] pntTriangle = { pntTo, pntRightHeadBase, pntLeftHeadBase };
			grpCanvas.FillPolygon(brsBrush, pntTriangle);
			grpCanvas.DrawPolygon(penPen, pntTriangle);
			//---
		}

		public static void DrawRuler(Graphics grpCanvas, Pen penPen, Brush brsBrush, Font fntFont, Rectangle recBounds, long lonTotalTicks, long lonTicksPerUnit)
		{
			// Draw the outline of the ruler
			grpCanvas.FillRectangle(brsBrush, recBounds);
			grpCanvas.DrawRectangle(penPen, recBounds);
			
			// Draw the main line of the ruler
			int intRulerX1 = recBounds.Left + 1;
			int intRulerX2 = recBounds.Right - 1;
			int intRulerY = recBounds.Top + recBounds.Height / 2;
			grpCanvas.DrawLine(penPen, new Point(intRulerX1, intRulerY), new Point(intRulerX2, intRulerY));
			
			//---
			// Draw the tick marks
			long lonCurrentTick = 0;
			int intTickHeight = recBounds.Height / 4;
			Brush brsTextBrush = new SolidBrush(penPen.Color);
			while(lonCurrentTick <= lonTotalTicks)
			{
				if((lonCurrentTick % lonTicksPerUnit) == 0)
				{
					// Draw the current tick mark
					double dblU = (double) lonCurrentTick / lonTotalTicks;
					int intTickX = (int) ((double) ((1.0 - dblU) * intRulerX1) + (dblU * intRulerX2));
					grpCanvas.DrawLine(penPen, new Point(intTickX, intRulerY + intTickHeight), new Point(intTickX, intRulerY - intTickHeight));

					// Draw the tick value string below the tick mark
					string strStringValue = lonCurrentTick.ToString();
					SizeF sizStringSize = grpCanvas.MeasureString(strStringValue, fntFont);
					PointF pntStringLocation = new PointF((float) intTickX - sizStringSize.Width / 2.0f, (float) intRulerY + intTickHeight + 1.0f);
					grpCanvas.DrawString(strStringValue, fntFont, brsTextBrush, pntStringLocation);
				}

				lonCurrentTick += lonTicksPerUnit;
			}
			//---
		}
		//-----------------------------------------------------------------
		#endregion
	}

}
